<?php
/**************************************************************************
Software released under the General Public License (version 2 or later), available at
http://www.gnu.org/copyleft/gpl.html

@copyright  GPL
@history    2006-03, Thierry Graff : Cretion
*************************************************************************/
?>
<html>
<head>
  <meta http-equiv="content-type" content="text/html; charset=utf-8">
  <style>
        body, .td{}
        .subtitle{ margin-bottom: 6px; margin-top: 20px; font-weight:bold; text-decoration:underline; font-size:2em; }
        .pluvio{ text-decoration:underline; }
        .td_number{ border:1px solid black; text-align:center; font-size:11px; }
    </style>
</head>

<body>
<h1 style="text-align:center">Evolution du stock d'eau</h1>

<?php
//
// ****************** 1 : Définition des données **************
//

// pluviométrie mensuelle, en mm.
$pluvio1 = array(85.5, 77.5, 57.4, 89.1, 82.2, 76, 40, 61, 115.9, 129.4, 126.5, 96.9);// pluviométrie moyenne
$pluvio2 = array(13,	20,	21,	19,	31,	4,	12,	13,	30,	66,	30,	10);// pluviométrie minimale

$q0 = 100; // quantité d'eau initiale (en début de simulation) en metres cubes
$coef = 0.8; // coefficient de ruissellement

// Surface de toit
$surface_toit1 = 212;
$surface_toit2 = 286;
$surface_toit3 = 339;

$conso_year = 115; // Consommation annuelle, en metres cubes

$conso = $conso_year*1000/365.25; // conso quotidienne en litres.

//
// ****************** FIN Définition des données **************
//

echo "<br/>Taille des citernes : <b>$q0</b> m<sup>3</sup>";
echo "<br/>Stock initial : <b>$q0</b> m<sup>3</sup>";
echo "<br/>Coefficient de ruissellement : <b>$coef</b> (toit en tuiles)";
echo "<br/>Consommation annuelle : <b>$conso_year</b> m<sup>3</sup>";
echo " (" . number_format($conso, 0, ',', ' ') . "</b> litres / jour)";


// ****************** 2 : Affichage des simulations **************

echo "<div class='subtitle'>Simulation 1</div>";
echo " Surface de toit : <b>$surface_toit1</b> m<sup>2</sup><br/>";
echo "<br/><div class='pluvio'>Pluviométrie moyenne</div>";
simulate($pluvio1, $surface_toit1, true, true);
echo "<BR><div class='pluvio'>Pluviométrie minimale</div>";
simulate($pluvio2, $surface_toit1, true, false);

echo "<div class='subtitle'>Simulation 2</div>";
echo " - surface de toit : <b>$surface_toit2</b> m<sup>2</sup><br/>";
echo "<br/><div class='pluvio'>Pluviométrie moyenne</div>";
simulate($pluvio1, $surface_toit2, false, true);
echo "<BR><div class='pluvio'>Pluviométrie minimale</div>";
simulate($pluvio2, $surface_toit2, false, false);

/*
$surface_toit = $surface_toit3;
echo "<H3 style='margin-bottom:0px;'>Cas 3 : surface 3</div>";
echo "<br/><b>Pluviométrie moyenne</b>";
simulate($pluvio1, false, true);
echo "<br/><BR><b>Pluviométrie minimale</b>";
echo simulate($pluvio2, false, false);
*/


//************************* simulate ***********************
/**
  Calcule et affiche l'évolution du stock d'eau
  @param $pluvio Pluviométrie considérée.
  @param $echoTable
  @param $echoNeededRain true ou false : afficher hauteur de pluie nécessaire pour satisfaire à la consommation annuelle ?
*/
function simulate($pluvio, $surface_toit, $echoTable, $echoNeededRain){
  global $q0, $conso, $coef, $conso_year;
  $nbDays = array(31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31);
  $months = array('J', 'F', 'M', 'A', 'M', 'J', 'J', 'A', 'S', 'O', 'N', 'D');
  //
  $total_pluvio = array_sum($pluvio);
  $total_water = round($total_pluvio * $coef * $surface_toit / 1000);
  echo "<b>$surface_toit m<sup>2</sup></b> de toiture peuvent récolter <b>$total_water m<sup>3</sup></b>.";
  if($echoNeededRain == true){
    $neededRain = calcNeededRain($surface_toit); // hauteur de pluie pour satisfaire à la consommation annuelle
    echo "<br/>Pour récolter $conso_year m<sup>3</sup>, il doit pleuvoir <b>$neededRain mm</b>.";
    if($echoTable) echo '<br/>';
  }
  $strTable = '';
  $strTable .= "<br/>";
  $strTable .= "<table cellspacing='0'>\n";
  $strTable .= "<tr>";
    $strTable .= "<td style='text-align:center; font-size:11px;'>&nbsp;</td>";
    for($i=0; $i < 12; $i++){
      $strTable .= "<td style='border:1px solid black; text-align:center; font-size:11px;'>{$months[$i]}</td>";
    }
    $strTable .= "<td style='border:1px solid black; text-align:center; font-size:11px;'>Somme</td>";
  $strTable .= "</tr>";
  /// pluvio
  $strTable .= "<tr>";
    $strTable .= "<td style='border:1px solid black; text-align:center; font-size:11px;'>Pluviométrie (mm)</td>";
    $sum = 0;
    for($i=0; $i < 12; $i++){
      $strTable .= "<td style='border:1px solid black; text-align:center; font-size:11px;'>{$pluvio[$i]}</td>";
      $sum += $pluvio[$i];
    }
    $strTable .= "<td style='border:1px solid black; text-align:center; font-size:11px;'><b>$sum</b></td>";
  $strTable .= "</tr>";
  /// eau recuperee
  $strTable .= "<tr>";
    $strTable .= "<td style='border:1px solid black; text-align:center; font-size:11px;'>Eau récupérée (m<sup>3</sup>)</td>";
    $sum = 0;
    for($i=0; $i < 12; $i++){
      $q = $surface_toit * $pluvio[$i] * $coef / 1000; // quantite d'eau recuperee en m cubes
      $strTable .= "<td style='border:1px solid black; text-align:center; font-size:11px;'>" . number_format($q, 2, ',', ' ') . "</td>";
      $sum += $q;
    }
    $strTable .= "<td style='border:1px solid black; text-align:center; font-size:11px;'><b>" . number_format($sum, 2, ',', ' ') . "</b></td>";
  $strTable .= "</tr>";
  ////// conso
  $conso_day = $conso / 1000; // conso quotidienne en m cubes
  $strTable .= "<tr>";
    $strTable .= "<td style='border:1px solid black; text-align:center; font-size:11px;'>Eau consommée (m<sup>3</sup>)</td>";
    $sum = 0;
    $stock = $q0;
    for($i=0; $i < 12; $i++){
      $conso_month = $conso_day *$nbDays[$i];
      $strTable .= "<td style='border:1px solid black; text-align:center; font-size:11px;'>" . number_format($conso_month, 2, ',', ' ') . "</td>";
      $sum += $conso_month;
    }
    $strTable .= "<td style='border:1px solid black; text-align:center; font-size:11px;'><b>" . number_format($sum, 2, ',', ' ') . "</b></td>";
  $strTable .= "</tr>";
  ////// stock
  $strTable .= "<tr>";
    $strTable .= "<td style='border:1px solid black; text-align:center; font-size:11px;'>Stock en fin de mois (m<sup>3</sup>)</td>";
    $stock = $q0;
    $lostQuantity = 0;
    for($i=0; $i < 12; $i++){
      $q = $surface_toit * $pluvio[$i] * $coef / 1000; // q = quantite d'eau recuperee en m cubes
      $stock = $stock + $q - $conso_day * $nbDays[$i];
      if($stock > $q0){
        $lostQuantity += $stock - $q0;
        $stock = $q0;
      }
      $strTable .= "<td style='border:1px solid black; text-align:center; font-size:11px;'><b>" . number_format($stock, 2, ',', ' ') . "</b></td>";
    }
    $lostQuantity = round($lostQuantity);
  $strTable .= "</tr>";
  $strTable .= "</TABLE>\n";
  if($echoTable == true) echo $strTable;
  echo "<br/>";
  if($stock == $q0){
    echo "<li style='list-style-image:url(includes/then.png)'><b>Au bout d'un an, stock renouvelé</b></li>";
  }
  else{
    $deficit = round($q0 - $stock);
    echo "<li style='list-style-image:url(includes/then.png)'><b>Au bout d'un an, stock déficitaire de $deficit m<sup>3</sup></b></li>";
  }
  echo "<li style='list-style-image:url(includes/then.png)'><b>Quantité non stockée : $lostQuantity m<sup>3</sup></b></li>";
}// end simulate


/**  Calcul hauteur de pluie nécessaire pour satisfaire à la consommation annuelle */
function calcNeededRain($surface_toit){
  global $conso_year, $coef;
  $neededRain = round($conso_year/($surface_toit*$coef)*1000);
  return $neededRain;
}

?>
</body>
</html>
